.. :changelog:

Release History
---------------

0.0.4 (2016-12-09)
++++++++++++++++++

**New Features**

- Full support for sessions.
- The core client now optionally waits for tasks.

**Miscellaneous**

- Documentation is updated and hosted via readthedocs.io.

0.0.3 (2016-11-23)
++++++++++++++++++

**New Features**

- Full support for service and application objects.

**Miscellaneous**

- All code confirmed to work with Python versions 2.7, 3.5, and in between.

0.0.2 (2016-11-21)
++++++++++++++++++

**New Features**

- Full support for access and NAT objects.
- Support for some misc. powerful features.

0.0.1 (2016-11-15)
++++++++++++++++++

**Features**

- Full support for policy package, simple gateway, host, group and network objects.
